@@ -1,8 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 #
-# This file is part of the Wapiti project (http://wapiti.sourceforge.net)
-# Copyright (C) 2017-2018 Nicolas Surribas
+# This file is part of the Wapiti project (https://wapiti-scanner.github.io)
+# Copyright (C) 2017-2023 Nicolas Surribas
+# Copyright (C) 2024 Cyberwatch
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,4 +18,5 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-parser_name = "html5lib"
+parser_name = "html.parser"
+WAPITI_VERSION = "3.2.0"
